@@ -3,7 +3,7 @@
 
     Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
     Copyright (C) 2008-2010 Golnaz Nilieh <g382nilieh@gmail.com>
-    Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -97,7 +97,7 @@ PostEntry::PostEntry(QWidget *parent)
     d->mTimer = new QTimer(this);
     d->mTimer->start(Settings::autosaveInterval() * MINUTE);
     connect(d->mTimer, &QTimer::timeout, this, &PostEntry::saveTemporary);
-    d->progress = Q_NULLPTR;
+    d->progress = nullptr;
     d->mCurrentPostBlogId = -1;
     d->mNumOfFilesToBeUploaded = 0;
     d->isPostContentModified = false;
@@ -474,7 +474,7 @@ void PostEntry::deleteProgressBar()
     if (d->progress) {
         this->layout()->removeWidget(d->progress);
         d->progress->deleteLater();
-        d->progress = Q_NULLPTR;
+        d->progress = nullptr;
     }
 }
 
